@@ -94,7 +94,8 @@ void command_save(gpointer callback_data,guint callback_action,
 				_("%s\nΥեϤǤ¸ߤޤ\n\n񤭤ޤ?"),
 																	ptw->file);
 		if ((!ptw->overwrite || !isfile(ptw->file)
-			|| message_box("Text maid",text,1,_("Ϥ"),_(""),NULL)==0)
+			|| message_box("Text maid",text,1,
+										_("Ϥ(_Y)"),_("(_N)"),NULL)==0)
 											&& save_text_file(ptw->file,ptw)) {
 			ptw->edit=FALSE;
 			if (delete_list(&ptw->undo)+delete_list(&ptw->redo)>0)
@@ -132,7 +133,8 @@ void command_saveas(gpointer callback_data,guint callback_action,
 				_("%s\nΥեϤǤ¸ߤޤ\n\n񤭤ޤ?"),
 															command_open_file);
 		if ((!ptw->overwrite || !isfile(command_open_file)
-			|| message_box("Text maid",text,1,_("Ϥ"),_(""),NULL)==0)
+			|| message_box("Text maid",text,1,
+										_("Ϥ(_Y)"),_("(_N)"),NULL)==0)
 									&& save_text_file(command_open_file,ptw)) {
 			/* ե̾Ĵ٤ */
 			delete_edit_file(ptw->file);
@@ -172,7 +174,8 @@ void command_reload(gpointer callback_data,guint callback_action,
 	if (ptw->edit) {
 		text=g_strdup_printf(_("ե %s ƤѹƤޤ\n"
 								"¸Ƥ֤ᤷޤ?"),ptw->file);
-		result=message_box("Text maid",text,1,_("Ϥ"),_(""),NULL);
+		result=message_box("Text maid",text,1,
+										_("Ϥ(_Y)"),_("(_N)"),NULL);
 		g_free(text);
 	}
 	if (result==0) {
@@ -304,17 +307,12 @@ void command_close(gpointer callback_data,guint callback_action,
 void command_exit(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	gint page;
-	TEXTWND *ptw;
+	GdkEvent event;
 
-	while ((page=gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))>=0) {
-		ptw=gtk_object_get_user_data(GTK_OBJECT(
-					gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),page)));
-		if (!prompt_close(ptw))
-			return;
-		gtk_notebook_remove_page(GTK_NOTEBOOK(notebook),page);
-	}
-	gtk_object_destroy(GTK_OBJECT(window));
+	event.any.type=GDK_DELETE;
+	event.any.window=window->window;
+	event.any.send_event=FALSE;
+	gdk_event_put(&event);
 }
 
 
@@ -356,7 +354,7 @@ void command_copy(gpointer callback_data,guint callback_action,
 	gint length;
 	TEXTWND *ptw;
 
-	if (gtk_selection_owner_set(window,clipboard_atom,GDK_CURRENT_TIME)) {
+	if (gtk_selection_owner_set(window,atom_clipboard,GDK_CURRENT_TIME)) {
 		ptw=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
@@ -374,8 +372,7 @@ void command_copy(gpointer callback_data,guint callback_action,
 void command_paste(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	gtk_selection_convert(window,clipboard_atom,
-							gdk_atom_intern("TARGETS",FALSE),GDK_CURRENT_TIME);
+	gtk_selection_convert(window,atom_clipboard,atom_targets,GDK_CURRENT_TIME);
 }
 
 
@@ -402,7 +399,7 @@ void command_margin(gpointer callback_data,guint callback_action,
 	TEXTWND *ptw;
 
 	if (message_box("Text maid",_("ޡǲԤޤ?"),1,
-											_("Ϥ"),_(""),NULL)==0) {
+									_("Ϥ(_Y)"),_("(_N)"),NULL)==0) {
 		ptw=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
@@ -417,7 +414,7 @@ void command_tab(gpointer callback_data,guint callback_action,
 	TEXTWND *ptw;
 
 	if (message_box("Text maid",_("֤򥹥ڡѴޤ?"),1,
-											_("Ϥ"),_(""),NULL)==0) {
+									_("Ϥ(_Y)"),_("(_N)"),NULL)==0) {
 		ptw=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
@@ -529,7 +526,7 @@ void command_find(gpointer callback_data,guint callback_action,
 		find_ignorecase=fd.ignorecase;
 		for (i=0;i<find_num;i++)
 			if (strcmp(fd.text,find_text[i])==0)
-					break;
+				break;
 		if (i==find_num) {
 			if (find_num>=32)
 				g_free(find_text[31]);
@@ -539,9 +536,11 @@ void command_find(gpointer callback_data,guint callback_action,
 			find_text[0]=fd.text;
 		} else {
 			g_free(fd.text);
-			text=find_text[i];
-			memmove(find_text+1,find_text,i*sizeof(gchar *));
-			find_text[0]=text;
+			if (i>0) {
+				text=find_text[i];
+				memmove(find_text+1,find_text,i*sizeof(gchar *));
+				find_text[0]=text;
+			}
 		}
 		command_next(callback_data,callback_action,widget);
 	}
@@ -600,7 +599,7 @@ void command_replace(gpointer callback_data,guint callback_action,
 		replace_ignorecase=rp.ignorecase;
 		for (i=0;i<find_num;i++)
 			if (strcmp(rp.src,find_text[i])==0)
-					break;
+				break;
 		if (i==find_num) {
 			if (find_num>=32)
 				g_free(find_text[31]);
