@@ -18,7 +18,6 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include "conf.h"
-#include "other.h"
 
 
 /******************************************************************************
@@ -93,6 +92,7 @@ static gboolean conf_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 
 void conf_dialog(void)
 {
+	guint key;
 	GtkAccelGroup *accel;
 	GtkWidget *dialog,*button1,*label0,*label1,*label2;
 	GtkWidget *frame,*hbox0,*hbox1,*vbox;
@@ -106,6 +106,9 @@ void conf_dialog(void)
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(conf_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
 	button0=gtk_button_new_with_label(_("λ"));
 	button1=gtk_button_new_with_label(_(""));
@@ -116,8 +119,18 @@ void conf_dialog(void)
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* åܥ */
-	check0=gtk_check_button_new_with_label(_("ե򳫤"));
-	check1=gtk_check_button_new_with_label(_("ɥ򳫤"));
+	check0=gtk_check_button_new_with_label(NULL);
+	check1=gtk_check_button_new_with_label(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
+												_("ե򳫤(_N)"));
+	gtk_widget_add_accelerator(check0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check1)->child),
+												_("ɥ򳫤(_O)"));
+	gtk_widget_add_accelerator(check1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),newfile);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),second);
 	gtk_signal_connect(GTK_OBJECT(check0),"toggled",conf_dialog_toggled,NULL);
@@ -145,32 +158,21 @@ void conf_dialog(void)
 	gtk_signal_connect(GTK_OBJECT(spin1),"changed",conf_dialog_changed,NULL);
 	gtk_signal_connect(GTK_OBJECT(spin2),"changed",conf_dialog_changed,NULL);
 	/* ٥ */
-	label0=gtk_label_new(_("ե"));
-	label1=gtk_label_new(_(""));
-	label2=gtk_label_new(_("⤵"));
-	/* 졼 */
-	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
-	gtk_widget_add_accelerator(spin0,"grab-focus",accel,'I',
+	label0=gtk_label_new(NULL);
+	label1=gtk_label_new(NULL);
+	label2=gtk_label_new(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(label0),_("ե(_I)"));
+	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,
 									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
 											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(label0,'I');
-	gtk_widget_add_accelerator(check0,"clicked",accel,'N',
+	key=gtk_label_parse_uline(GTK_LABEL(label1),_("(_W)"));
+	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,
 									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
 											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check0)->child,'N');
-	gtk_widget_add_accelerator(check1,"clicked",accel,'O',
+	key=gtk_label_parse_uline(GTK_LABEL(label2),_("⤵(_H)"));
+	gtk_widget_add_accelerator(spin2,"grab-focus",accel,key,
 									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
 											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check1)->child,'O');
-	gtk_widget_add_accelerator(spin1,"grab-focus",accel,'W',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(label1,'W');
-	gtk_widget_add_accelerator(spin2,"grab-focus",accel,'H',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(label2,'H');
 	/* ե졼ȥܥå */
 	frame=gtk_frame_new(_("ɥΥ"));
 	vbox=gtk_vbox_new(FALSE,0);
