@@ -351,18 +351,17 @@ TEXTWND *open_edit_file(gchar *file)
 									GTK_SIGNAL_FUNC(signal_unrealize),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"configure-event",
 									GTK_SIGNAL_FUNC(signal_config),ptw);
-	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"expose_event",
+	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"expose-event",
 									GTK_SIGNAL_FUNC(signal_expose),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"button-press-event",
 									GTK_SIGNAL_FUNC(signal_button_press),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"motion-notify-event",
-                      				GTK_SIGNAL_FUNC(signal_motion_notify),ptw);
+									GTK_SIGNAL_FUNC(signal_motion_notify),ptw);
 	gtk_signal_connect_after(GTK_OBJECT(ptw->drawing),"key-press-event",
 									GTK_SIGNAL_FUNC(signal_key_press),ptw);
 	gtk_signal_connect(GTK_OBJECT(ptw->drawing),"destroy",
-                      				GTK_SIGNAL_FUNC(signal_destroy_draw),ptw);
-	gtk_widget_add_events(ptw->drawing,GDK_FOCUS_CHANGE
-					| GDK_BUTTON_PRESS_MASK | GDK_2BUTTON_PRESS
+									GTK_SIGNAL_FUNC(signal_destroy_draw),ptw);
+	gtk_widget_add_events(ptw->drawing,GDK_FOCUS_CHANGE | GDK_BUTTON_PRESS_MASK
 					| GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK);
 	GTK_WIDGET_SET_FLAGS(ptw->drawing,GTK_CAN_FOCUS);
 	/* С */
@@ -426,7 +425,7 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 		p=p->prev;
 	/*  */
 	if ((fp=fopen(file,"wt"))==NULL) {
-		message_box("Text maid",_("ե뤬ޤ"),0,"OK",NULL);
+		message_box("Text maid",_("ե뤬ޤ"),0,_("λ"),NULL);
 		return FALSE;
 	}
 	/* ܥå */
@@ -439,18 +438,18 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 			gtk_main_iteration();
 		if (p->length>0 && fwrite(p->text,1,p->length,fp)!=p->length) {
 			gtk_grab_remove(dialog);
-		    gtk_widget_destroy(dialog);
+			gtk_widget_destroy(dialog);
 			message_box("Text maid",_("ե˽񤭹ߤǤޤ"),0,
-																	"OK",NULL);
+															_("λ"),NULL);
 			fclose(fp);
 			return FALSE;
 		}
 		if (!p->margin && p->next!=NULL) {
 			if (fputc('\n',fp)==EOF) {
 				gtk_grab_remove(dialog);
-			    gtk_widget_destroy(dialog);
+				gtk_widget_destroy(dialog);
 				message_box("Text maid",_("ե˽񤭹ߤǤޤ"),0,
-																	"OK",NULL);
+															_("λ"),NULL);
 				fclose(fp);
 				return FALSE;
 			}
@@ -463,16 +462,17 @@ gboolean save_text_file(gchar *file,TEXTWND *ptw)
 	/* Ǹ^Zդä */
 	if (userbreak && !eof && ptw->eof && fputc('\x1a',fp)==EOF) {
 		gtk_grab_remove(dialog);
-	    gtk_widget_destroy(dialog);
-		message_box("Text maid",_("ե˽񤭹ߤǤޤ"),0,"OK",NULL);
+		gtk_widget_destroy(dialog);
+		message_box("Text maid",_("ե˽񤭹ߤǤޤ"),0,
+															_("λ"),NULL);
 		fclose(fp);
 		return FALSE;
 	}
 	/* λ */
 	gtk_grab_remove(dialog);
-    gtk_widget_destroy(dialog);
+	gtk_widget_destroy(dialog);
 	if (fclose(fp)!=0) {
-		message_box("Text maid","fclose",0,"OK",NULL);
+		message_box("Text maid","fclose",0,_("λ"),NULL);
 		return FALSE;
 	}
 	return TRUE;
