@@ -80,8 +80,8 @@ static gboolean find_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 gboolean find_dialog(FIND *fd)
 {
 	gint i;
+	guint key;
 	GList *glist=NULL;
-	GSList *group=NULL;
 	GtkAccelGroup *accel;
 	GtkWidget *radio0,*button0,*button1,*frame0,*frame1,*hbox,*tbox,*vbox;
 
@@ -91,8 +91,16 @@ gboolean find_dialog(FIND *fd)
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(find_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
-	button0=gtk_button_new_with_label(_(""));
+	button0=gtk_button_new_with_label(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
+																_("(_F)"));
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	button1=gtk_button_new_with_label(_(""));
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",find_dialog_clicked,fd);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
@@ -100,7 +108,12 @@ gboolean find_dialog(FIND *fd)
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* åܥ */
-	check=gtk_check_button_new_with_label(_("ʸ/ʸ̤"));
+	check=gtk_check_button_new_with_label(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
+											_("ʸ/ʸ̤(_C)"));
+	gtk_widget_add_accelerator(check,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),fd->ignorecase);
 	/* ܥܥå */
 	for (i=0;i<find_num;i++)
@@ -116,31 +129,19 @@ gboolean find_dialog(FIND *fd)
 	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"changed",
 												find_dialog_changed,button0);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(group,_(""));
-	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio0));
-	radio1=gtk_radio_button_new_with_label(group,_(""));
-	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio1));
+	radio0=gtk_radio_button_new_with_label(NULL,NULL);
+	radio1=gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON(radio0),NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_U)"));
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_D)"));
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fd->arrow?radio1:radio0),
 																		TRUE);
-	/* 졼 */
-	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
-	gtk_widget_add_accelerator(check,"clicked",accel,'C',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check)->child,'C');
-	gtk_widget_add_accelerator(radio0,"clicked",accel,'U',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(radio0)->child,'U');
-	gtk_widget_add_accelerator(radio1,"clicked",accel,'D',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(radio1)->child,'D');
-	gtk_widget_add_accelerator(button0,"clicked",accel,'F',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button0)->child,'F');
 	/* ե졼ȥܥå */
 	tbox=gtk_vbox_new(FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
@@ -234,7 +235,7 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 	ptw->cursor.x=get_align_pos(&ptw->start,&ptw->off,
 								ptw->cursor.x,ptw->cursor.y,ptw->tab,FALSE);
 	length0=strlen(find);
-	text=g_malloc((length0+1)*sizeof(gchar));
+	text=g_malloc((length0+2)*sizeof(gchar));
 	if (ptw->select.x>=0) {
 		/* ϰϤ */
 		select=ptw->select;
@@ -335,8 +336,8 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 				break;
 			}
 			/* ХåեƬʸ˴ */
-			if (iskanji(text[0])) {
-				memmove(text,text+2,(length0-2)*sizeof(gchar));
+			if (iskanji(text[0]) && length1>=2) {
+				memmove(text,text+2,length0*sizeof(gchar));
 				length1-=2;
 				if (st.x<p->length) {
 					st.x+=2;
@@ -345,8 +346,8 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 					st.y++;
 					p=p->next;
 				}
-			} else {
-				memmove(text,text+1,(length0-1)*sizeof(gchar));
+			} else if (length1>0) {
+				memmove(text,text+1,(length0+1)*sizeof(gchar));
 				length1--;
 				if (st.x<p->length) {
 					st.x++;
