@@ -20,7 +20,6 @@
 #include <gdk/gdkkeysyms.h>
 #include "format.h"
 #include "general.h"
-#include "other.h"
 #include "prop.h"
 
 
@@ -146,6 +145,7 @@ static gboolean format_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 void format_dialog(void)
 {
 	gint i;
+	guint key;
 	GtkAccelGroup *accel;
 	GtkWidget *dialog,*button5,*clist,*scroll,*hbox,*vbox;
 
@@ -156,6 +156,9 @@ void format_dialog(void)
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 								GTK_SIGNAL_FUNC(format_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ꥹȥܥå */
 	clist=gtk_clist_new(1);
 	gtk_clist_set_column_title(GTK_CLIST(clist),0,
@@ -176,12 +179,37 @@ void format_dialog(void)
 										GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scroll),clist);
 	/* ܥ */
-	button0=gtk_button_new_with_label(_(""));
-	button1=gtk_button_new_with_label(_(""));
-	button2=gtk_button_new_with_label(_(""));
-	button3=gtk_button_new_with_label(_(""));
-	button4=gtk_button_new_with_label(_("Խ"));
+	button0=gtk_button_new_with_label(NULL);
+	button1=gtk_button_new_with_label(NULL);
+	button2=gtk_button_new_with_label(NULL);
+	button3=gtk_button_new_with_label(NULL);
+	button4=gtk_button_new_with_label(NULL);
 	button5=gtk_button_new_with_label(_("Ĥ"));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
+																_("(_N)"));
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
+																_("(_R)"));
+	gtk_widget_add_accelerator(button1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),
+																_("(_U)"));
+	gtk_widget_add_accelerator(button2,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button3)->child),
+																_("(_D)"));
+	gtk_widget_add_accelerator(button3,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button4)->child),
+																_("Խ(_E)"));
+	gtk_widget_add_accelerator(button4,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 										format_dialog_clicked_new,clist);
 	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
@@ -200,29 +228,6 @@ void format_dialog(void)
 	GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button4,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button5,GTK_CAN_DEFAULT);
-	/* 졼 */
-	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
-	gtk_widget_add_accelerator(button0,"clicked",accel,'N',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button0)->child,'N');
-	gtk_widget_add_accelerator(button1,"clicked",accel,'R',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button1)->child,'R');
-	gtk_widget_add_accelerator(button2,"clicked",accel,'U',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button2)->child,'U');
-	gtk_widget_add_accelerator(button3,"clicked",accel,'D',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button3)->child,'D');
-	gtk_widget_add_accelerator(button4,"clicked",accel,'E',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button4)->child,'E');
 	/* ܥå */
 	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),scroll,TRUE,TRUE,8);
