@@ -601,7 +601,7 @@ gboolean prompt_close(TEXTWND *ptw)
 					_("ե %s ƤѹƤޤ\n¸ޤ?"),
 																	ptw->file);
 		switch (message_box("Text maid",text,0,
-								_("Ϥ"),_(""),_("󥻥"),NULL)) {
+						_("Ϥ(_Y)"),_("(_N)"),_("󥻥"),NULL)) {
 			case 0:
 				command_save(NULL,0,NULL);
 				if (!ptw->edit)
