@@ -47,12 +47,6 @@ gboolean isfile(gchar *file);
 gchar *get_full_path(gchar *file);
 
 
-/*	٥ʸ˲Ĥ
-	label,٥
-	  key,ʸ																*/
-void set_label_pattern(GtkWidget *label,gchar key);
-
-
 /*	Сꤹ
 	   scroll,륦å
 	     func,ʥؿ
