@@ -18,7 +18,6 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include "ftype.h"
-#include "other.h"
 #include "prop.h"
 
 
@@ -296,6 +295,7 @@ gboolean property_dialog(FTYPE *ft)
 {
 	gchar *xpm[18];
 	gint i;
+	guint key;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
 	GtkAccelGroup *accel;
@@ -311,13 +311,33 @@ gboolean property_dialog(FTYPE *ft)
 							GTK_SIGNAL_FUNC(property_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
 	gtk_widget_show(dialog);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("ѹ"));
-	button1=gtk_button_new_with_label(_("ե"));
+	button0=gtk_button_new_with_label(NULL);
+	button1=gtk_button_new_with_label(NULL);
 	button2=ft->text==NULL && ft->ext==NULL
-						?gtk_button_new_with_label(_("ե륿")):NULL;
+										?gtk_button_new_with_label(NULL):NULL;
 	button3=gtk_button_new_with_label(_("λ"));
 	button4=gtk_button_new_with_label(_(""));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
+																_("ѹ(_P)"));
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
+															_("ե(_F)"));
+	gtk_widget_add_accelerator(button1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	if (button2!=NULL) {
+		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),
+													_("ե륿(_A)"));
+		gtk_widget_add_accelerator(button2,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	}
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 										property_dialog_clicked_color,NULL);
 	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
@@ -330,18 +350,72 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_signal_connect_object(GTK_OBJECT(button4),"clicked",
 										gtk_widget_destroy,GTK_OBJECT(dialog));
 	/* åܥ */
-	check0=gtk_check_button_new_with_label(_("å"));
-	check1=gtk_check_button_new_with_label(_("ѥڡ"));
-	check2=gtk_check_button_new_with_label(_("ԥ"));
-	check3=gtk_check_button_new_with_label(_("ޡɽ"));
-	check4=gtk_check_button_new_with_label(_("ޤ֤"));
-	check5=gtk_check_button_new_with_label(_("ʸ"));
-	check6=gtk_check_button_new_with_label(_(""));
-	check7=gtk_check_button_new_with_label(_(""));
-	check8=gtk_check_button_new_with_label(
-										_("եκǸ^Z(1A)դ"));
-	check9=gtk_check_button_new_with_label(_("¸ǧ"));
-	check10=gtk_check_button_new_with_label(_("ƥ࿧Ȥ"));
+	check0=gtk_check_button_new_with_label(NULL);
+	check1=gtk_check_button_new_with_label(NULL);
+	check2=gtk_check_button_new_with_label(NULL);
+	check3=gtk_check_button_new_with_label(NULL);
+	check4=gtk_check_button_new_with_label(NULL);
+	check5=gtk_check_button_new_with_label(NULL);
+	check6=gtk_check_button_new_with_label(NULL);
+	check7=gtk_check_button_new_with_label(NULL);
+	check8=gtk_check_button_new_with_label(NULL);
+	check9=gtk_check_button_new_with_label(NULL);
+	check10=gtk_check_button_new_with_label(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
+															_("å(_G)"));
+	gtk_widget_add_accelerator(check0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check1)->child),
+														_("ѥڡ(_S)"));
+	gtk_widget_add_accelerator(check1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check2)->child),
+														_("ԥ(_E)"));
+	gtk_widget_add_accelerator(check2,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check3)->child),
+													_("ޡɽ(_M)"));
+	gtk_widget_add_accelerator(check3,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check4)->child),
+															_("ޤ֤(_I)"));
+	gtk_widget_add_accelerator(check4,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check5)->child),
+														_("ʸ(_C)"));
+	gtk_widget_add_accelerator(check5,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check6)->child),_("(_U)"));
+	gtk_widget_add_accelerator(check6,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check7)->child),_("(_V)"));
+	gtk_widget_add_accelerator(check7,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check8)->child),
+									_("եκǸ^Z(1A)դ(_Z)"));
+	gtk_widget_add_accelerator(check8,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check9)->child),
+												_("¸ǧ(_O)"));
+	gtk_widget_add_accelerator(check9,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check10)->child),
+													_("ƥ࿧Ȥ(_Y)"));
+	gtk_widget_add_accelerator(check10,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	if (check11!=NULL) {
+	}
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),ft->gline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),ft->space);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),ft->crlf);
@@ -376,8 +450,12 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_signal_connect(GTK_OBJECT(check10),"toggled",
 											property_dialog_toggled,NULL);
 	if (ft->text!=NULL && ft->ext!=NULL) {
-		check11=gtk_check_button_new_with_label(
-											_("ե륿פϢŤ"));
+		check11=gtk_check_button_new_with_label(NULL);
+		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check11)->child),
+										_("ե륿פϢŤ(_A)"));
+		gtk_widget_add_accelerator(check11,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check11),ft->associate);
 		gtk_signal_connect(GTK_OBJECT(check11),"toggled",
 											property_dialog_ok_sensitive,NULL);
@@ -400,13 +478,19 @@ gboolean property_dialog(FTYPE *ft)
 		gtk_signal_connect(GTK_OBJECT(entry1),"activate",
 												property_dialog_clicked_ok,ft);
 	} else {
-		for (i=0;i<ftnum;i++)
-			if (ft->ft_id==ftype[i].ft_id) {
-				label=gtk_label_new(ftype[i].text);
-				break;
-			}
-		if (label==NULL)
+		if (ft->ft_id>=0) {
+			/* ե륿פ */
+			for (i=0;i<ftnum;i++)
+				if (ft->ft_id==ftype[i].ft_id) {
+					label=gtk_label_new(ftype[i].text);
+					break;
+				}
+			if (label==NULL)
+				label=gtk_label_new(_("ե륿"));
+		} else {
+			/* ե륿פʤ */
 			label=gtk_label_new(_("ե륿פʤ"));
+		}
 		gtk_misc_set_alignment(GTK_MISC(label),0,0.5);
 		entry0=entry1=NULL;
 	}
@@ -455,73 +539,6 @@ gboolean property_dialog(FTYPE *ft)
 											property_dialog_ok_sensitive,NULL);
 	gtk_signal_connect(GTK_OBJECT(spin1),"changed",
 											property_dialog_ok_sensitive,NULL);
-	/* 졼 */
-	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
-	gtk_widget_add_accelerator(button0,"clicked",accel,'P',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button0)->child,'P');
-	gtk_widget_add_accelerator(button1,"clicked",accel,'F',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button1)->child,'F');
-	if (button2!=NULL) {
-		gtk_widget_add_accelerator(button2,"clicked",accel,'A',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-		set_label_pattern(GTK_BIN(button2)->child,'A');
-	}
-	gtk_widget_add_accelerator(check0,"clicked",accel,'G',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check0)->child,'G');
-	gtk_widget_add_accelerator(check1,"clicked",accel,'S',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check1)->child,'S');
-	gtk_widget_add_accelerator(check2,"clicked",accel,'E',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check2)->child,'E');
-	gtk_widget_add_accelerator(check3,"clicked",accel,'M',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check3)->child,'M');
-	gtk_widget_add_accelerator(check4,"clicked",accel,'I',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check4)->child,'I');
-	gtk_widget_add_accelerator(check5,"clicked",accel,'C',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check5)->child,'C');
-	gtk_widget_add_accelerator(check6,"clicked",accel,'U',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check6)->child,'U');
-	gtk_widget_add_accelerator(check7,"clicked",accel,'V',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check7)->child,'V');
-	gtk_widget_add_accelerator(check8,"clicked",accel,'Z',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check8)->child,'Z');
-	gtk_widget_add_accelerator(check9,"clicked",accel,'O',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check9)->child,'O');
-	gtk_widget_add_accelerator(check10,"clicked",accel,'Y',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check10)->child,'Y');
-	if (check11!=NULL) {
-		gtk_widget_add_accelerator(check11,"clicked",accel,'A',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-		set_label_pattern(GTK_BIN(check11)->child,'A');
-	}
 	/* ե졼ȥܥå */
 	tbox=gtk_hbox_new(FALSE,0);
 	if (entry0!=NULL && entry1!=NULL) {
