@@ -18,7 +18,6 @@
 */
 #include <gdk/gdkkeysyms.h>
 #include "find.h"
-#include "other.h"
 #include "replace.h"
 
 
@@ -92,8 +91,8 @@ static gboolean replace_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 gint replace_dialog(REPLACE *rp)
 {
 	gint i;
+	guint key;
 	GList *glist=NULL;
-	GSList *group=NULL;
 	GtkAccelGroup *accel;
 	GtkWidget *radio0,*button2;
 	GtkWidget *frame0,*frame1,*hbox,*tbox,*vbox;
@@ -104,10 +103,23 @@ gint replace_dialog(REPLACE *rp)
 	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
 							GTK_SIGNAL_FUNC(replace_dialog_key_press),NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	/* 졼 */
+	accel=gtk_accel_group_new();
+	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
 	/* ܥ */
-	button0=gtk_button_new_with_label(_("ִ"));
-	button1=gtk_button_new_with_label(_("٤ִ"));
+	button0=gtk_button_new_with_label(NULL);
+	button1=gtk_button_new_with_label(NULL);
 	button2=gtk_button_new_with_label(_(""));
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
+																_("ִ(_R)"));
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
+														_("٤ִ(_A)"));
+	gtk_widget_add_accelerator(button1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 												replace_dialog_clicked_ok,rp);
 	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
@@ -118,7 +130,12 @@ gint replace_dialog(REPLACE *rp)
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
 	/* åܥ */
-	check=gtk_check_button_new_with_label(_("ʸ/ʸ̤"));
+	check=gtk_check_button_new_with_label(NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
+											_("ʸ/ʸ̤(_C)"));
+	gtk_widget_add_accelerator(check,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),rp->ignorecase);
 	/* ܥܥå */
 	for (i=0;i<find_num;i++)
@@ -146,35 +163,19 @@ gint replace_dialog(REPLACE *rp)
 	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo1)->entry),"activate",
 												replace_dialog_activate,rp);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(group,_(""));
-	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio0));
-	radio1=gtk_radio_button_new_with_label(group,_(""));
-	group=gtk_radio_button_group(GTK_RADIO_BUTTON(radio1));
+	radio0=gtk_radio_button_new_with_label(NULL,NULL);
+	radio1=gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON(radio0),NULL);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_U)"));
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_D)"));
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
+									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rp->arrow?radio1:radio0),
 																		TRUE);
-	/* 졼 */
-	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
-	gtk_widget_add_accelerator(check,"clicked",accel,'C',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(check)->child,'C');
-	gtk_widget_add_accelerator(radio0,"clicked",accel,'U',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(radio0)->child,'U');
-	gtk_widget_add_accelerator(radio1,"clicked",accel,'D',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(radio1)->child,'D');
-	gtk_widget_add_accelerator(button0,"clicked",accel,'R',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button0)->child,'R');
-	gtk_widget_add_accelerator(button1,"clicked",accel,'A',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
-	set_label_pattern(GTK_BIN(button1)->child,'A');
 	/* ե졼ȥܥå */
 	tbox=gtk_vbox_new(FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
