@@ -1274,7 +1274,7 @@ gboolean signal_selection_clear(GtkWidget *widget,GdkEventSelection *event,
 {
 	if (event->selection==GDK_SELECTION_PRIMARY) {
 		has_selection=FALSE;
-	} else if (event->selection==clipboard_atom) {
+	} else if (event->selection==atom_clipboard) {
 		g_free(clipboard_text);
 		clipboard_text=NULL;
 	}
@@ -1303,13 +1303,13 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 				str[length]='\0';
 			}
 		}
-	} else if (data->selection==clipboard_atom) {
+	} else if (data->selection==atom_clipboard) {
 		/* åץܡ */
 		if (clipboard_text!=NULL) {
 			str=clipboard_text;
 			length=strlen(clipboard_text);
 		}
-	} else if (data->selection==textmaid_atom) {
+	} else if (data->selection==atom_textmaid) {
 		/* ץ̿ */
 		str="Text maid Selection";
 		length=strlen(str);
@@ -1345,7 +1345,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 	GdkAtom *atoms;
 	GdkPoint select;
 
-	if (data->selection==clipboard_atom) {
+	if (data->selection==atom_clipboard) {
 		/* åץܡ */
 		if (data->length>=0) {
 			if (data->type==GDK_SELECTION_TYPE_ATOM) {
@@ -1353,17 +1353,14 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 				count=data->length/sizeof(GdkAtom);
 				for (i=0;i<count;i++)
 					if (atoms[i]==GDK_TARGET_STRING
-							|| atoms[i]==gdk_atom_intern("COMPOUND_TEXT",FALSE)
-							|| atoms[i]==gdk_atom_intern("TEXT",FALSE))
+							|| atoms[i]==atom_compound || atoms[i]==atom_text)
 						break;
 				if (i<count)
-					gtk_selection_convert(window,clipboard_atom,atoms[i],
+					gtk_selection_convert(widget,atom_clipboard,atoms[i],
 															GDK_CURRENT_TIME);
 			} else if (data->type==GDK_TARGET_STRING) {
-				data->data[data->length]='\0';
 				text=g_strdup(data->data);
-			} else if (data->type==gdk_atom_intern("COMPOUND_TEXT",FALSE)
-								|| data->type==gdk_atom_intern("TEXT",FALSE)) {
+			} else if (data->type==atom_compound || data->type==atom_text) {
 				count=gdk_text_property_to_text_list(data->type,data->format,
 												data->data,data->length,&list);
 				if (count>0) {
@@ -1390,7 +1387,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 			ptw->edit=TRUE;
 			g_free(text);
 		}
-	} else if (data->selection==textmaid_atom) {
+	} else if (data->selection==atom_textmaid) {
 		/* ץ̿ */
 		instance=MAX(data->length,0);
 	}
@@ -1404,7 +1401,7 @@ gboolean signal_client_event(GtkWidget *widget,GdkEventClient *event,
 	COMM *p;
 	TEXTWND *ptw;
 
-	if (event->message_type==textmaid_atom) {
+	if (event->message_type==atom_textmaid) {
 		for (p=comm;p!=NULL;p=p->next)
 			if (p->pid==event->data.l[4])
 				break;
