@@ -51,8 +51,11 @@ gint tcount=0;						/* ե륿פΥ */
 guint timer_id=0;					/* ID */
 COMM *comm=NULL;					/* ץ̿ѹ¤ */
 FTYPE *ftype=NULL;					/* ե륿 */
-GdkAtom clipboard_atom;				/* åץܡ */
-GdkAtom textmaid_atom;				/* ץ̿ѥȥ */
+GdkAtom atom_clipboard;				/* åץܡ */
+GdkAtom atom_targets;				/* å */
+GdkAtom atom_compound;				/* ѥ */
+GdkAtom atom_text;					/* ƥ */
+GdkAtom atom_textmaid;				/* ץ̿ѥȥ */
 GtkWidget *window;					/* ɥ */
 GtkWidget *notebook;				/* Ρȥ֥å */
 GtkWidget *status;					/* ơɥ */
@@ -466,19 +469,21 @@ int main(int argc,char *argv[])
 	gtk_drag_dest_set(window,GTK_DEST_DEFAULT_MOTION
 						| GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP,
 												drag_types,1,GDK_ACTION_COPY);
-	gtk_signal_connect(GTK_OBJECT(window),"drag_data_received",
-						    GTK_SIGNAL_FUNC(signal_drag_data_received),NULL);
+	gtk_signal_connect(GTK_OBJECT(window),"drag-data-received",
+							GTK_SIGNAL_FUNC(signal_drag_data_received),NULL);
 	/* åץܡ/ץ̿ */
-	clipboard_atom=gdk_atom_intern("CLIPBOARD",FALSE);
-	textmaid_atom=gdk_atom_intern("Text maid InterProcess communication",
+	atom_clipboard=gdk_atom_intern("CLIPBOARD",FALSE);
+	atom_targets=gdk_atom_intern("TARGETS",FALSE);
+	atom_compound=gdk_atom_intern("COMPOUND_TEXT",FALSE);
+	atom_text=gdk_atom_intern("TEXT",FALSE);
+	atom_textmaid=gdk_atom_intern("Text maid InterProcess communication",
 																		FALSE);
 	gtk_selection_add_targets(window,GDK_SELECTION_PRIMARY,
 							targets,sizeof(targets)/sizeof(GtkTargetEntry));
-	gtk_selection_add_targets(window,clipboard_atom,
+	gtk_selection_add_targets(window,atom_clipboard,
 							targets,sizeof(targets)/sizeof(GtkTargetEntry));
 	if (!second)
-		gtk_selection_add_targets(window,textmaid_atom,
-							targets,sizeof(targets)/sizeof(GtkTargetEntry));
+		gtk_selection_add_targets(window,atom_textmaid,targets,1);
 	gtk_signal_connect(GTK_OBJECT(window),"selection-clear-event",
 								GTK_SIGNAL_FUNC(signal_selection_clear),NULL);
 	gtk_signal_connect(GTK_OBJECT(window),"selection-get",
@@ -560,7 +565,7 @@ int main(int argc,char *argv[])
 
 	/* ˵ưƤ뤫å */
 	if (!second) {
-		gtk_selection_convert(window,textmaid_atom,
+		gtk_selection_convert(window,atom_textmaid,
 								GDK_SELECTION_TYPE_STRING,GDK_CURRENT_TIME);
 		while (instance<0)
 			while (gtk_events_pending())
@@ -570,7 +575,7 @@ int main(int argc,char *argv[])
 			event.type=GDK_CLIENT_EVENT;
 			event.window=window->window;
 			event.send_event=TRUE;
-			event.message_type=textmaid_atom;
+			event.message_type=atom_textmaid;
 			event.data_format=32;
 			event.data.l[0]=init_line;
 			event.data.l[4]=getpid();
@@ -579,7 +584,6 @@ int main(int argc,char *argv[])
 			for (i=1;i<argc;i++)
 				if (arg_files[i]) {
 					str=get_full_path(argv[i]);
-					g_print("%s\n",str);
 					leng=strlen(str)+1;
 					for (j=0;j<leng;j+=16) {
 						memcpy(event.data.b,str+j,MIN(leng-j,16));
@@ -592,7 +596,7 @@ int main(int argc,char *argv[])
 		}
 		gtk_signal_connect(GTK_OBJECT(window),"client-event",
 									GTK_SIGNAL_FUNC(signal_client_event),NULL);
-		gtk_selection_owner_set(window,textmaid_atom,GDK_CURRENT_TIME);
+		gtk_selection_owner_set(window,atom_textmaid,GDK_CURRENT_TIME);
 	}
 
 	/* ɽ */
