@@ -136,8 +136,11 @@ extern gint tcount;						/* ե륿פΥ */
 extern guint timer_id;					/* ID */
 extern COMM *comm;						/* ץ̿ѹ¤ */
 extern FTYPE *ftype;					/* ե륿 */
-extern GdkAtom clipboard_atom;			/* åץܡ */
-extern GdkAtom textmaid_atom;			/* ץ̿ѥȥ */
+extern GdkAtom atom_clipboard;			/* åץܡ */
+extern GdkAtom atom_targets;			/* å */
+extern GdkAtom atom_compound;			/* ѥ */
+extern GdkAtom atom_text;				/* ƥ */
+extern GdkAtom atom_textmaid;			/* ץ̿ѥȥ */
 extern GtkWidget *window;				/* ɥ */
 extern GtkWidget *notebook;				/* Ρȥ֥å */
 extern GtkWidget *status;				/* ơɥ */
